@@ -278,3 +278,13 @@ def process(
 
     # For any other error, print details about what happened and clean up
     #  any created file and folder
+    except Exception as e:
+        log.error(f"Job failed with error: {e}")
+        pipeline.delete_folder(base_path)
+
+        # Clear up logging handlers so subsequent executions in the same python thread
+        #  don't stack up
+        if log.hasHandlers():
+            log.handlers.clear()
+
+        return {"status": 1, "errormsg": e}
