@@ -6,19 +6,45 @@ from oais_utils.validate import validate_sip
 from .. import main
 
 """
-All these tests cover different supported pipelines. 
-Based on the parameters given at the test_variables, 
-each function calls the pipeline_results() which runs bagit-create and 
+All these tests cover different supported pipelines.
+Based on the parameters given at the test_variables,
+each function calls the pipeline_results() which runs bagit-create and
 validates the result using the oais_utils.validate method and returns True or False.
 """
 
 
-def test_indico_pipeline():
-    test_variables = {"source": "indico", "recid": 1024767, "dry_run": False}
+def test_codimd_pipeline():
+    test_variables = {
+        "source": "codimd",
+        # This note should be set as EDITABLE and be PUBLISHED or it
+        # won't be accessible without a token
+        "recid": "tBD632vFt",
+        "dry_run": False,
+    }
     valid = pipeline_results(
-        test_variables["source"], test_variables["recid"], test_variables["dry_run"]
+        test_variables["source"],
+        test_variables["recid"],
+        test_variables["dry_run"],
     )
-    assert valid == True
+    assert valid is True
+
+
+def test_indico_pipeline():
+    # So we can keep INDICO_KEY uncommitted and read it from an environment variable set for the ci/cd job
+    token = os.environ["INDICO_KEY"]
+    test_variables = {
+        "source": "indico",
+        "recid": 1024767,
+        "dry_run": False,
+        "token": token,
+    }
+    valid = pipeline_results(
+        test_variables["source"],
+        test_variables["recid"],
+        test_variables["dry_run"],
+        test_variables["token"],
+    )
+    assert valid is True
 
 
 def test_cds_pipeline():
@@ -26,7 +52,7 @@ def test_cds_pipeline():
     valid = pipeline_results(
         test_variables["source"], test_variables["recid"], test_variables["dry_run"]
     )
-    assert valid == True
+    assert valid is True
 
 
 """
@@ -44,7 +70,7 @@ def test_zenodo_pipeline():
     valid = pipeline_results(
         test_variables["source"], test_variables["recid"], test_variables["dry_run"]
     )
-    assert valid == True
+    assert valid is True
 
 
 def test_cod_pipeline():
@@ -52,7 +78,8 @@ def test_cod_pipeline():
     valid = pipeline_results(
         test_variables["source"], test_variables["recid"], test_variables["dry_run"]
     )
-    assert valid == True
+    assert valid is True
+
 
 """
 def test_inveniordm_pipeline():
@@ -63,14 +90,20 @@ def test_inveniordm_pipeline():
     assert valid == True
 """
 
-def pipeline_results(source, recid, dry_run):
+
+def pipeline_results(source, recid, dry_run, token=None):
     # Prepare a temporary folder to save the results
     with tempfile.TemporaryDirectory() as tmpdir1:
 
         # Run Bagit Create with the following parameters:
         # Save the results to tmpdir1
         main.process(
-            recid=recid, source=source, loglevel=0, target=tmpdir1, dry_run=dry_run
+            recid=recid,
+            source=source,
+            loglevel=0,
+            target=tmpdir1,
+            dry_run=dry_run,
+            token=token,
         )
 
         # Check inside the tmpdir1 for any folders. If it finds one, this will be the folder created by Bagit Create.
